==> qtjambi-network-debuginfo-macos-5.15.17.jar: sources/QtJambiNetwork/QDtlsClientVerifier_shell.h <==
#ifndef QDTLSCLIENTVERIFIER_SHELL_H
#define QDTLSCLIENTVERIFIER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <qtnetwork-config.h>
#if QT_CONFIG(dtls)
#include <QtNetwork/qdtls.h>
#endif //QT_CONFIG(dtls)
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtNetwork/qhostaddress.h>
#include <QtNetwork/qudpsocket.h>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(dtls)

class QDtlsClientVerifier_shell : public QDtlsClientVerifier, public QtJambiShellInterface
{
public:
    QDtlsClientVerifier_shell(QObject* parent0 = nullptr);
    ~QDtlsClientVerifier_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QDtlsClientVerifier_access : public QDtlsClientVerifier
{
};

#endif // QT_CONFIG(dtls)
#endif // QDTLSCLIENTVERIFIER_SHELL_H

==> qtjambi-network-debuginfo-macos-6.5.3.jar: sources/QtJambiNetwork/QDtlsClientVerifier_shell.h <==
#ifndef QDTLSCLIENTVERIFIER_SHELL_H
#define QDTLSCLIENTVERIFIER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <qtnetwork-config.h>
#if QT_CONFIG(dtls)
#include <QtNetwork/qdtls.h>
#endif //QT_CONFIG(dtls)
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtNetwork/qhostaddress.h>
#include <QtNetwork/qudpsocket.h>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(dtls)

class QDtlsClientVerifier_shell : public QDtlsClientVerifier, public QtJambiShellInterface
{
public:
    QDtlsClientVerifier_shell(QObject* parent0 = nullptr);
    ~QDtlsClientVerifier_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QDtlsClientVerifier_access : public QDtlsClientVerifier
{
};

#endif // QT_CONFIG(dtls)
#endif // QDTLSCLIENTVERIFIER_SHELL_H
